@@ -9,7 +9,7 @@ class Lambda:
         self.logger = Logger("DNX Lambda =>")
 
     def invoke(self, name, pay_load=None):
-        self.logger.info("Starting Invoke Lambda")
+        self.logger.debug("Starting Invoke Lambda")
         response = lambda_client.invoke(
             FunctionName=name,
             InvocationType='Event',
@@ -17,11 +17,11 @@ class Lambda:
         )
 
         if response.get("StatusCode") == 202:
-            self.logger.info("Invoke Lambda Success")
+            self.logger.debug("Invoke Lambda Success")
         else:
-            self.logger.info(
+            self.logger.debug(
                 "Failed Invoke Lambda {}"
                 .format(response)
             )
 
-        self.logger.info("Finishing Invoke Lambda")
+        self.logger.debug("Finishing Invoke Lambda")
